;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "google-translate" "20250115.609"
  "Emacs interface to Google Translate."
  '((emacs "24.3")
    (popup "0.5.8"))
  :url "https://github.com/atykhonov/google-translate"
  :commit "e84599df7c70870b33dd6c902b527d7f78310815"
  :revdesc "e84599df7c70"
  :keywords '("convenience")
  :authors '(("Oleksandr Manzyuk" . "manzyuk@gmail.com"))
  :maintainers '(("Andrey Tykhonov" . "atykhonov@gmail.com")))
